Compile-time hash value calculation (was: Patch for the php bug 47815)

From: Date: Tue, 31 Mar 2009 18:36:06 +0000
Subject: Compile-time hash value calculation (was: Patch for the php bug 47815)
References: 1  Groups: php.internals 
Request: Send a blank email to internals+get-43562@lists.php.net to get a copy of this message
Hi Basant, I've updated you patch for 5.3 (attached, don't forget to regenerate zend_vm_execute.h). 5.2 is closed for such changes anyway and I don't think the patch should be applied into 5.3 too, because it is in RC stage. I got ~10% speed-up on very synthetic benchmarks (b.php attached). The speed difference on real-life applications without opcode caches is invisible. I wasn't able to test it with caches. In general the idea is very interesting, but as I mentioned before I don't like extension of zend_opcode and tricky usage of object handlers. It should be done in some more general way. Anyway, please check if my changes didn't make your patch slower. May be someone would like to play with patch and make it better... Thanks. Dmitry. Basant Kukreja wrote: > Attached is the patch for bug 47815 > http://bugs.php.net/bug.php?id=47815 > > I applied this patch on php-5.2.9 and it applied cleanly. > > Thanks for looking into the patch. > > Regards, > Basant. > >

« previous php.internals (#43562) next »